@@ -4,7 +4,13 @@ set -ex
 
 DAEMON_TIMEOUT=60
 CRM_TIMEOUT=5
-NODE=$(hostname)
+NODE="$(uname -n)"
+
+# https://bugs.launchpad.net/bugs/1828228
+ulimit -H -l unlimited 2>/dev/null || {
+	echo "test disabled for unprivileged namespaces"
+	exit 77
+}
 
 #
 # daemons start
@@ -18,31 +24,31 @@ sleep $DAEMON_TIMEOUT
 # online
 #
 
-crm status | grep "^Online:.*$NODE"
+crm status | grep "Online:.*$NODE"
 
 #
 # standby
 #
 
-crm node standby
+crm node standby $NODE
 sleep $CRM_TIMEOUT
-crm status | grep "^Node $NODE: standby"
+crm status | grep "Node $NODE: standby"
 
-crm node online
+crm node online $NODE
 sleep $CRM_TIMEOUT
-crm status | grep "^Online:.*$NODE"
+crm status | grep "Online:.*$NODE"
 
 #
 # maintenance
 #
 
-crm node maintenance
+crm node maintenance $NODE
 sleep $CRM_TIMEOUT
-crm status | grep "^Node $NODE: maintenance"
+crm status | grep "Node $NODE: maintenance"
 
-crm node ready
+crm node ready $NODE
 sleep $CRM_TIMEOUT
-crm status | grep "^Online:.*$NODE"
+crm status | grep "Online:.*$NODE"
 
 #
 # attributes
